==> react-8.0.1.tgz: package/es/Modal/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
/** Library that manages Tabbing and Accessibility for Modal
 *   https://github.com/davidtheclark/react-aria-modal
 */

import AriaModal from 'react-aria-modal';
/**
 * @category containers
 * @component modal
 * @variations collab-ui-react
 */

var Modal =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Modal, _React$Component);

  function Modal() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      animationClass: _this.props.show ? 'in' : ''
    };

    _this.getChildContext = function () {
      return {
        handleClose: function handleClose(e) {
          return _this.closeModal(e);
        }
      };
    };

    _this.closeModal = function (e) {
      _this.setAnimationState();

      return setTimeout(function () {
        _this.props.onHide(e);
      }, 300);
    };

    _this.setAnimationState = function (isOpen) {
      _this.setState({
        animationClass: isOpen ? 'in' : ''
      });
    };

    return _this;
  }

  var _proto = Modal.prototype;

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    prevProps.show !== this.props.show && this.props.show && this.setAnimationState(true);
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        applicationId = _this$props.applicationId,
        backdrop = _this$props.backdrop,
        backdropClickExit = _this$props.backdropClickExit,
        children = _this$props.children,
        className = _this$props.className,
        escapeExits = _this$props.escapeExits,
        focusDialog = _this$props.focusDialog,
        htmlId = _this$props.htmlId,
        icon = _this$props.icon,
        renderTo = _this$props.renderTo,
        show = _this$props.show,
        size = _this$props.size,
        props = _objectWithoutProperties(_this$props, ["applicationId", "backdrop", "backdropClickExit", "children", "className", "escapeExits", "focusDialog", "htmlId", "icon", "renderTo", "show", "size"]);

    var getIcon = function getIcon() {
      if (icon.type.displayName === 'Icon') {
        return icon;
      }

      throw new Error("icon prop needs to be of type Icon.");
    };

    var modalContent = React.createElement("div", {
      className: "cui-modal__content"
    }, icon && size === 'dialog' && getIcon() && React.createElement("div", {
      className: "cui-modal__content--left-pane"
    }, icon), React.createElement("div", {
      className: "cui-modal__content--right-pane"
    }, children));
    var RenderModal = renderTo ? AriaModal.renderTo("#" + renderTo) : AriaModal;

    var getModal = function getModal() {
      return show && React.createElement(RenderModal, _extends({
        onExit: _this2.closeModal,
        getApplicationNode: function getApplicationNode() {
          return document.querySelector("#" + applicationId);
        },
        dialogClass: "cui-modal" + (" cui-modal--" + size) + (" " + _this2.state.animationClass) + ("" + (className && " " + className || '')),
        includeDefaultStyles: false,
        titleId: htmlId,
        underlayClass: backdrop ? "cui-modal__backdrop fade" + (" " + _this2.state.animationClass) : '',
        underlayClickExits: backdropClickExit,
        escapeExits: escapeExits,
        focusDialog: focusDialog
      }, props), modalContent);
    };

    return getModal();
  };

  return Modal;
}(React.Component);

Modal.displayName = 'Modal';
Modal.childContextTypes = {
  handleClose: PropTypes.func
};
Modal.defaultProps = {
  backdrop: true,
  backdropClickExit: false,
  children: null,
  className: '',
  escapeExits: true,
  focusDialog: true,
  icon: null,
  renderTo: null,
  show: false,
  size: 'default'
};
Modal.propTypes = {
  /**
  * application DOM id, used to set aria-hidden to true when modal is open.
  */
  applicationId: PropTypes.string.isRequired,

  /**
   *  To show/hide backdrop of the modal.
   *  if backdrop is false then modal will become normal popup without backdrop and user can perform any action in parent screen.
   */
  backdrop: PropTypes.bool,

  /**
   *  To enable/disable clicking on underlay to exit modal
   *
   */
  backdropClickExit: PropTypes.bool,

  /**
   * Children components
   */
  children: PropTypes.node,

  /**
   * css class names
   */
  className: PropTypes.string,

  /**
   *  To enable/disable escape to exit modal
   *
   */
  escapeExits: PropTypes.bool,

  /**
   * To set focus to the entire modal rather than elements within modal
   */
  focusDialog: PropTypes.bool,

  /** Unique HTML ID. Used for tying label to HTML input. Handy hook for automated testing. */
  htmlId: PropTypes.string.isRequired,

  /**
   * Icon node to be rendered for Dialog
   */
  icon: PropTypes.element,

  /**
   * callback function invoked on close of the modal. modal can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed modal can not be closed.
   */
  onHide: PropTypes.func.isRequired,

  /**
   * To render to an element other than the window
   */
  renderTo: PropTypes.string,

  /**
   * show/hide modal.
   */
  show: PropTypes.bool.isRequired,

  /**
   * size of the modal.
   */
  size: PropTypes.oneOf(['large', 'medium', 'default', 'small', 'full', 'dialog'])
};
export default Modal;
/**
* @name Default Modal
* @description Modal with default size.
* @category containers
* @component modal
* @section default
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Default/Medium Modal'
              onClick={() => this.setState({showModal: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal: false})}
            show={this.state.showModal}
            ref={modal1 => this.modal1 = modal1}
            htmlId='modal1'
            backdropClickExit
          >
            <ModalHeader
              headerLabel='Default Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal1.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal1.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}

**/

/**
* @name Dialog Modal
* @description Modal with dialog size.
* @category containers
* @component modal
* @section dialog
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader,
  Icon
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal2: false,
    showModalInternal: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Dialog Modal'
              onClick={() => this.setState({showModal2: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
            <Button
              children='Render To Div'
              onClick={() => this.setState({showModalInternal: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            icon={<Icon name="warning_72" color="$yellow"/>}
            applicationId='app'
            onHide={() => this.setState({showModal2: false})}
            show={this.state.showModal2}
            ref={modal2 => this.modal2 = modal2}
            size='dialog'
            htmlId='modal2'
          >
            <ModalHeader
              headerLabel='Dialog Modal'
            />
            <ModalBody>
              <span>I'm just a dialog box</span>
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal2.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                onClick={() => this.modal2.closeModal()}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
        <div id='render-to-modal'/>
        <div>
          <Modal
            icon={<Icon name="warning_72" color="$yellow"/>}
            applicationId='app'
            onHide={() => this.setState({showModalInternal: false})}
            show={this.state.showModalInternal}
            ref={ref => this.modalInternal = ref}
            size='dialog'
            htmlId='modalInternal'
            renderTo='render-to-modal'
          >
            <ModalHeader
              headerLabel='Dialog Modal'
            />
            <ModalBody>
              <span>I'm just a dialog box</span>
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modalInternal.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                onClick={() => this.modalInternal.closeModal()}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}

**/

/**
* @name Small Modal
* @description Modal with small size.
* @category containers
* @component modal
* @section small
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader,
  Form
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal3: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Small Modal'
              onClick={() => this.setState({showModal3: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal3: false})}
            show={this.state.showModal3}
            ref={modal3 => this.modal3 = modal3}
            size='small'
            htmlId='modal3'
          >
            <ModalHeader
              headerLabel='Small Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={moform2 => this.moform2 = moform2} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal3.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault;
                  this.modal3.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/

/**
* @name Large Modal
* @description Modal with large size.
* @category containers
* @component modal
* @section large
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal4: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Large Modal'
              onClick={() => this.setState({showModal4: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal4: false})}
            show={this.state.showModal4}
            ref={modal4 => this.modal4 = modal4}
            htmlId='modal4'
            size='large'
          >
            <ModalHeader
              headerLabel='Large Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal4.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal4.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/

/**
* @name Full Modal
 * @description Modal with full size.
* @category containers
* @component modal
* @section full
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal4: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Full Modal'
              onClick={() => this.setState({showModal4: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal4: false})}
            show={this.state.showModal4}
            ref={modal5 => this.modal5 = modal5}
            htmlId='modal5'
            size='full'
          >
            <ModalHeader
              headerLabel='Full Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal5.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal5.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/

==> react-8.3.0.tgz: package/es/Modal/index.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.keys";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
/** Library that manages Tabbing and Accessibility for Modal
 *   https://github.com/davidtheclark/react-aria-modal
 */

import AriaModal from 'react-aria-modal';
/**
 * @category containers
 * @component modal
 * @variations collab-ui-react
 */

var Modal =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(Modal, _React$Component);

  function Modal() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.state = {
      animationClass: _this.props.show ? 'in' : ''
    };

    _this.getChildContext = function () {
      return {
        handleClose: function handleClose(e) {
          return _this.closeModal(e);
        }
      };
    };

    _this.closeModal = function (e) {
      _this.setAnimationState();

      return setTimeout(function () {
        _this.props.onHide(e);
      }, 300);
    };

    _this.setAnimationState = function (isOpen) {
      _this.setState({
        animationClass: isOpen ? 'in' : ''
      });
    };

    return _this;
  }

  var _proto = Modal.prototype;

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    prevProps.show !== this.props.show && this.props.show && this.setAnimationState(true);
  };

  _proto.render = function render() {
    var _this2 = this;

    var _this$props = this.props,
        applicationId = _this$props.applicationId,
        backdrop = _this$props.backdrop,
        backdropClickExit = _this$props.backdropClickExit,
        children = _this$props.children,
        className = _this$props.className,
        escapeExits = _this$props.escapeExits,
        focusDialog = _this$props.focusDialog,
        htmlId = _this$props.htmlId,
        icon = _this$props.icon,
        renderTo = _this$props.renderTo,
        show = _this$props.show,
        size = _this$props.size,
        props = _objectWithoutPropertiesLoose(_this$props, ["applicationId", "backdrop", "backdropClickExit", "children", "className", "escapeExits", "focusDialog", "htmlId", "icon", "renderTo", "show", "size"]);

    var getIcon = function getIcon() {
      if (icon.type.displayName === 'Icon') {
        return icon;
      }

      throw new Error("icon prop needs to be of type Icon.");
    };

    var modalContent = React.createElement("div", {
      className: "cui-modal__content"
    }, icon && size === 'dialog' && getIcon() && React.createElement("div", {
      className: "cui-modal__content--left-pane"
    }, icon), React.createElement("div", {
      className: "cui-modal__content--right-pane"
    }, children));
    var RenderModal = renderTo ? AriaModal.renderTo("#" + renderTo) : AriaModal;

    var getModal = function getModal() {
      return show && React.createElement(RenderModal, _extends({
        onExit: _this2.closeModal,
        getApplicationNode: function getApplicationNode() {
          return document.querySelector("#" + applicationId);
        },
        dialogClass: "cui-modal" + (" cui-modal--" + size) + (" " + _this2.state.animationClass) + ("" + (className && " " + className || '')),
        includeDefaultStyles: false,
        titleId: htmlId,
        underlayClass: backdrop ? "cui-modal__backdrop fade" + (" " + _this2.state.animationClass) : '',
        underlayClickExits: backdropClickExit,
        escapeExits: escapeExits,
        focusDialog: focusDialog
      }, props), modalContent);
    };

    return getModal();
  };

  return Modal;
}(React.Component);

Modal.displayName = 'Modal';
Modal.childContextTypes = {
  handleClose: PropTypes.func
};
Modal.defaultProps = {
  backdrop: true,
  backdropClickExit: false,
  children: null,
  className: '',
  escapeExits: true,
  focusDialog: true,
  icon: null,
  renderTo: null,
  show: false,
  size: 'default'
};
Modal.propTypes = {
  /**
  * application DOM id, used to set aria-hidden to true when modal is open.
  */
  applicationId: PropTypes.string.isRequired,

  /**
   *  To show/hide backdrop of the modal.
   *  if backdrop is false then modal will become normal popup without backdrop and user can perform any action in parent screen.
   */
  backdrop: PropTypes.bool,

  /**
   *  To enable/disable clicking on underlay to exit modal
   *
   */
  backdropClickExit: PropTypes.bool,

  /**
   * Children components
   */
  children: PropTypes.node,

  /**
   * css class names
   */
  className: PropTypes.string,

  /**
   *  To enable/disable escape to exit modal
   *
   */
  escapeExits: PropTypes.bool,

  /**
   * To set focus to the entire modal rather than elements within modal
   */
  focusDialog: PropTypes.bool,

  /** Unique HTML ID. Used for tying label to HTML input. Handy hook for automated testing. */
  htmlId: PropTypes.string.isRequired,

  /**
   * Icon node to be rendered for Dialog
   */
  icon: PropTypes.element,

  /**
   * callback function invoked on close of the modal. modal can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed modal can not be closed.
   */
  onHide: PropTypes.func.isRequired,

  /**
   * To render to an element other than the window
   */
  renderTo: PropTypes.string,

  /**
   * show/hide modal.
   */
  show: PropTypes.bool.isRequired,

  /**
   * size of the modal.
   */
  size: PropTypes.oneOf(['large', 'medium', 'default', 'small', 'full', 'dialog'])
};
export default Modal;
/**
* @name Default Modal
* @description Modal with default size.
* @category containers
* @component modal
* @section default
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Default/Medium Modal'
              onClick={() => this.setState({showModal: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal: false})}
            show={this.state.showModal}
            ref={modal1 => this.modal1 = modal1}
            htmlId='modal1'
            backdropClickExit
          >
            <ModalHeader
              headerLabel='Default Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal1.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal1.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}

**/

/**
* @name Dialog Modal
* @description Modal with dialog size.
* @category containers
* @component modal
* @section dialog
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader,
  Icon
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal2: false,
    showModalInternal: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Dialog Modal'
              onClick={() => this.setState({showModal2: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
            <Button
              children='Render To Div'
              onClick={() => this.setState({showModalInternal: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            icon={<Icon name="warning_72" color="$yellow"/>}
            applicationId='app'
            onHide={() => this.setState({showModal2: false})}
            show={this.state.showModal2}
            ref={modal2 => this.modal2 = modal2}
            size='dialog'
            htmlId='modal2'
          >
            <ModalHeader
              headerLabel='Dialog Modal'
            />
            <ModalBody>
              <span>I'm just a dialog box</span>
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal2.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                onClick={() => this.modal2.closeModal()}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
        <div id='render-to-modal'/>
        <div>
          <Modal
            icon={<Icon name="warning_72" color="$yellow"/>}
            applicationId='app'
            onHide={() => this.setState({showModalInternal: false})}
            show={this.state.showModalInternal}
            ref={ref => this.modalInternal = ref}
            size='dialog'
            htmlId='modalInternal'
            renderTo='render-to-modal'
          >
            <ModalHeader
              headerLabel='Dialog Modal'
            />
            <ModalBody>
              <span>I'm just a dialog box</span>
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modalInternal.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                onClick={() => this.modalInternal.closeModal()}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}

**/

/**
* @name Small Modal
* @description Modal with small size.
* @category containers
* @component modal
* @section small
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader,
  Form
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal3: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Small Modal'
              onClick={() => this.setState({showModal3: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal3: false})}
            show={this.state.showModal3}
            ref={modal3 => this.modal3 = modal3}
            size='small'
            htmlId='modal3'
          >
            <ModalHeader
              headerLabel='Small Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={moform2 => this.moform2 = moform2} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal3.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault;
                  this.modal3.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/

/**
* @name Large Modal
* @description Modal with large size.
* @category containers
* @component modal
* @section large
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal4: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Large Modal'
              onClick={() => this.setState({showModal4: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal4: false})}
            show={this.state.showModal4}
            ref={modal4 => this.modal4 = modal4}
            htmlId='modal4'
            size='large'
          >
            <ModalHeader
              headerLabel='Large Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal4.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal4.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/

/**
* @name Full Modal
 * @description Modal with full size.
* @category containers
* @component modal
* @section full
*
* @js

import {
  Button,
  ModalBody,
  ModalFooter,
  ModalHeader
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    showModal4: false
  }

  render() {
    return (
      <section>
        <div className='row'>
          <div>
            <Button
              children='Full Modal'
              onClick={() => this.setState({showModal4: true})}
              ariaLabel='Open Modal'
              color='primary'
            />
          </div>
        </div>
        <div>
          <Modal
            applicationId='app'
            onHide={() => this.setState({showModal4: false})}
            show={this.state.showModal4}
            ref={modal5 => this.modal5 = modal5}
            htmlId='modal5'
            size='full'
          >
            <ModalHeader
              headerLabel='Full Modal'
              showCloseButton
            />
            <ModalBody>
              <form ref={form1 => this.form1 = form1} />
            </ModalBody>
            <ModalFooter>
              <Button
                children='Cancel'
                onClick={() => this.modal5.closeModal()}
                ariaLabel='Close Modal'
                color='default'
              />
              <Button
                children='OK'
                type='submit'
                onClick={(e) => {
                  e.preventDefault();
                  this.modal5.closeModal();
                }}
                ariaLabel='Submit Form'
                color='blue'
              />
            </ModalFooter>
          </Modal>
        </div>
      </section>
    );
  }
}
**/
